jQuery UI Effects Test Suite

WHAT: A set of elements with various box-model properties, using the shake effect to toggle.

EXPECTED: When clicking "Toggle", all elements should not change dimension nor position, aside from the expected shake animation, which should take the number of milliseconds specified to complete. At the end of the animation, all elements should hide.

EXPECTED: Clicking "Toggle" a second time reverses the animation, first showing all elements at their original dimensions, and restoring them to their original state.

test
test
test
test
test
test
test
test
test
test
test
test
test
test
test